@@ -406,9 +406,9 @@ crs.formula <- function(formula,
                         initial.mesh.size.real="r1.0e-01", 
                         initial.mesh.size.integer="1",
                         min.mesh.size.real=paste(sqrt(.Machine$double.eps)),
-                        min.mesh.size.integer=1,  #paste(sqrt(.Machine$double.eps)),
-                        min.poll.size.real=paste(sqrt(.Machine$double.eps)),
-                        min.poll.size.integer=1, #paste(sqrt(.Machine$double.eps)),
+                        min.mesh.size.integer=1,
+                        min.poll.size.real=1,
+                        min.poll.size.integer=1,
                         opts=list(),
                         nmulti=5,
                         tau=NULL,
