@@ -26,8 +26,8 @@ frscvNOMAD <- function(xz,
                        random.seed=42,
                        max.bb.eval=10000,
                        initial.mesh.size.integer="1",
-                       min.mesh.size.integer=paste("r",sqrt(.Machine$double.eps),sep=""),
-                       min.poll.size.integer=paste("r",sqrt(.Machine$double.eps),sep=""),
+                       min.mesh.size.integer="1", #paste("r",sqrt(.Machine$double.eps),sep=""),
+                       min.poll.size.integer="1",  #paste("r",sqrt(.Machine$double.eps),sep=""),
                        opts=list(),
                        nmulti=0,
                        tau=NULL,
